@@ -38,7 +38,11 @@
 !     eb      = (true,false) configures for the use of a
 !               (euler backward,forward) type mixing timestep
 
-!     init_time = (true,false) sets restart time to initial condition
+!     init_time     = (true,false) sets restarts to initial time
+
+!     init_time_in  = (true,false) sets input restart to initial time
+
+!     init_time_out = (true,false) sets output restart to initial time
 
 !-----------------------------------------------------------------------
 !     inputs to tmngr.F: diagnostic intervals
@@ -292,7 +296,7 @@
 !     osege  =  true on the last time step of an ocean segment in mom.F
 !               otherwise false.
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 
       character(8) :: rununits
       common /switc_c/ rununits
@@ -310,8 +314,8 @@
       common /switc_l/ itavg, itmb, itrmb, igyre
       common /switc_l/  eoday, eoweek, eo2wks
       common /switc_l/  eomon, midmon, eoyear, eorun
-      logical init_time
-      common /switc_l/  init_time
+      logical init_time, init_time_in, init_time_out
+      common /switc_l/  init_time, init_time_in, init_time_out
 
       real runlen, rundays
       common /switc_r/ runlen, rundays
